@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2021 openpyxl
+# Copyright (c) 2010-2024 openpyxl
 
 from collections import defaultdict
 from itertools import chain
@@ -79,12 +79,11 @@ class DataValidation(Serialisable):
     cells = Alias("sqref")
     ranges = Alias("sqref")
 
-    showErrorMessage = Bool()
     showDropDown = Bool(allow_none=True)
     hide_drop_down = Alias('showDropDown')
-    showInputMessage = Bool()
-    showErrorMessage = Bool()
-    allowBlank = Bool()
+    showInputMessage = Bool(allow_none=True)
+    showErrorMessage = Bool(allow_none=True)
+    allowBlank = Bool(allow_none=True)
     allow_blank = Alias('allowBlank')
 
     errorTitle = String(allow_none = True)
@@ -108,11 +107,10 @@ class DataValidation(Serialisable):
                  type=None,
                  formula1=None,
                  formula2=None,
-                 allow_blank=False,
-                 showErrorMessage=True,
-                 showInputMessage=True,
-                 showDropDown=None,
-                 allowBlank=None,
+                 showErrorMessage=False,
+                 showInputMessage=False,
+                 showDropDown=False,
+                 allowBlank=False,
                  sqref=(),
                  promptTitle=None,
                  errorStyle=None,
@@ -121,6 +119,7 @@ class DataValidation(Serialisable):
                  errorTitle=None,
                  imeMode=None,
                  operator=None,
+                 allow_blank=None,
                  ):
         self.sqref = sqref
         self.showDropDown = showDropDown
@@ -198,6 +197,6 @@ class DataValidationList(Serialisable):
         """
         ranges = self.dataValidation # copy
         self.dataValidation = [r for r in self.dataValidation if bool(r.sqref)]
-        xml = super(DataValidationList, self).to_tree(tagname)
+        xml = super().to_tree(tagname)
         self.dataValidation = ranges
         return xml
